import { Request, Response } from "express";
import { Route, RouteMessages } from "server";
import { nodeManager } from "..";

export default class ProxyRoute extends Route {
  constructor() {
    super({ path: "/" });
  }

  async handle(req: Request, res: Response) {
    const url = req.url.substring(1);
    if (!url) {
      res.status(400).json(RouteMessages.badRequest("No URL provided"));
      return;
    }

    const node = nodeManager.getRandomNode();
    if (!node) {
      res
        .status(500)
        .json(RouteMessages.internalServerError("No nodes available"));
      return;
    }

    const response = await node.fetch(url);
    const data = response.data;

    // Return the JSON response
    res.status(response.status).set(response.headers).json(data);
  }
}
